| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell98 |
NLP.Nerf.Tokenize
Contents
Description
The module implements the tokenization used within Nerf and some other tokenization-related stuff.
nerf-0.5.3: Nerf, the named entity recognition tool based on linear-chain CRFs
| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell98 |
NLP.Nerf.Tokenize
Contents
Description
The module implements the tokenization used within Nerf and some other tokenization-related stuff.